<?php

namespace Drupal\message_digest\Plugin\Notifier;

use Drupal\user\UserInterface;

/**
 * Interface for sending messages as digests.
 */
interface DigestInterface {

  /**
   * Aggregate all of the messages for this digest.
   *
   * Collect all messages for the digest's interval and notifier that haven't
   * already been sent, and group them by user and then by group.
   *
   * @return array
   *   An array of message IDs, keyed by user ID, then by entity_type, then by
   *   entity_id.
   *
   * @code
   *   $aggregate = [
   *     23 => [
   *       '' => [
   *         // Non-grouped message digests here.
   *         12, 24,
   *       ],
   *       'node' => [
   *         23 => [1, 3, 5],
   *       ],
   *     ];
   * @endcode
   */
  public function aggregate();

  /**
   * Mark the sent digest messages as sent in the message_digest DB table.
   *
   * @param \Drupal\user\UserInterface $account
   *   User account for which to mark the digest as sent.
   */
  public function markSent(UserInterface $account);

  /**
   * Sets the last sent time.
   */
  public function setLastSent();

}
